@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -26,9 +26,6 @@
  *
  ************************************************************************/
 
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
 #include <tools/debug.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/svapp.hxx>
@@ -47,7 +44,7 @@
 #include <svl/cjkoptions.hxx>
 #include <com/sun/star/i18n/TransliterationModules.hpp>
 #include <comphelper/processfactory.hxx>
-#include <svx/svxdlg.hxx> 
+#include <svx/svxdlg.hxx>
 #include <sal/macros.h>
 
 using namespace ::com::sun::star::uno;
@@ -85,7 +82,6 @@ void FmSearchDialog::initCommon( const Reference< XResultSet >& _rxCursor )
         m_aHalfFullFormsCJK.Hide();
 
         // never ignore the width (ignoring is expensive) if the option is not available at all
-        // 04.12.2001 - 91973 - fs@openoffice.org
         m_pSearchEngine->SetIgnoreWidthCJK( sal_False );
     }
 
@@ -132,9 +128,9 @@ FmSearchDialog::FmSearchDialog(Window* pParent, const UniString& sInitialText, c
     ,m_pbHelp                   (this, CUI_RES(1))
     ,m_sSearch                  ( m_pbSearchAgain.GetText() )
     ,m_sCancel                  ( Button::GetStandardText( BUTTON_CANCEL ) )
-    ,m_pPreSearchFocus( NULL )                                      
+    ,m_pPreSearchFocus( NULL )
     ,m_lnkContextSupplier(lnkContextSupplier)
-    ,m_pConfig( NULL )                                              
+    ,m_pConfig( NULL )
 {
     DBG_ASSERT(m_lnkContextSupplier.IsSet(), "FmSearchDialog::FmSearchDialog : have no ContextSupplier !");
 
@@ -203,9 +199,9 @@ FmSearchDialog::FmSearchDialog(Window* pParent, const UniString& sInitialText, c
 
 //------------------------------------------------------------------------
 void FmSearchDialog::implMoveControls(
-            Control** _ppControls, 
-            sal_Int32 _nControls, 
-            sal_Int32 _nUp, 
+            Control** _ppControls,
+            sal_Int32 _nControls,
+            sal_Int32 _nUp,
             Control* /*_pToResize*/)
 {
     for (sal_Int32 i=0; i<_nControls; ++i)
@@ -241,7 +237,7 @@ FmSearchDialog::~FmSearchDialog()
 //------------------------------------------------------------------------
 void FmSearchDialog::Init(const UniString& strVisibleFields, const UniString& sInitialText)
 {
-    // die Initialisierung all der Controls
+    //the initialization of all the Controls
     m_rbSearchForText.SetClickHdl(LINK(this, FmSearchDialog, OnClickedFieldRadios));
     m_rbSearchForNull.SetClickHdl(LINK(this, FmSearchDialog, OnClickedFieldRadios));
     m_rbSearchForNotNull.SetClickHdl(LINK(this, FmSearchDialog, OnClickedFieldRadios));
@@ -269,9 +265,9 @@ void FmSearchDialog::Init(const UniString& strVisibleFields, const UniString& sI
     m_aHalfFullFormsCJK.SetToggleHdl(LINK(this, FmSearchDialog, OnCheckBoxToggled));
     m_aSoundsLikeCJK.SetToggleHdl(LINK(this, FmSearchDialog, OnCheckBoxToggled));
 
-    // die Listboxen fuellen
-    // die Methoden des Feldvergleiches
-    USHORT nResIds[] = {
+    // fill the listboxes
+    // method of field comparison
+    sal_uInt16 nResIds[] = {
         RID_STR_SEARCH_ANYWHERE,
         RID_STR_SEARCH_BEGINNING,
         RID_STR_SEARCH_END,
@@ -281,8 +277,8 @@ void FmSearchDialog::Init(const UniString& strVisibleFields, const UniString& sI
         m_lbPosition.InsertEntry( String( CUI_RES( nResIds[i] ) ) );
     m_lbPosition.SelectEntryPos(MATCHING_ANYWHERE);
 
-    // die Feld-Listbox
-    for (USHORT i=0; i<strVisibleFields.GetTokenCount(';'); ++i)
+    // the field listbox
+    for (sal_uInt16 i=0; i<strVisibleFields.GetTokenCount(';'); ++i)
         m_lbField.InsertEntry(strVisibleFields.GetToken(i, ';'));
 
 
@@ -290,14 +286,15 @@ void FmSearchDialog::Init(const UniString& strVisibleFields, const UniString& sI
     LoadParams();
 
     m_cmbSearchText.SetText(sInitialText);
-    // wenn die Edit-Zeile den Text veraendert hat (weil er zum Beispiel Steuerzeichen enthielt, wie das bei Memofeldern der Fall
-    // sein kann), nehme ich einen leeren UniString
+    // if the Edit-line has changed the text (e.g. because it contains
+    // control characters, as can be the case with memo fields), I use
+    // an empty UniString.
     UniString sRealSetText = m_cmbSearchText.GetText();
     if (!sRealSetText.Equals(sInitialText))
         m_cmbSearchText.SetText(UniString());
     LINK(this, FmSearchDialog, OnSearchTextModified).Call(&m_cmbSearchText);
 
-    // initial die ganzen UI-Elemente fuer die Suche an
+    // initial
     m_aDelayedPaint.SetTimeoutHdl(LINK(this, FmSearchDialog, OnDelayedPaint));
     m_aDelayedPaint.SetTimeout(500);
     EnableSearchUI(sal_True);
@@ -311,8 +308,10 @@ void FmSearchDialog::Init(const UniString& strVisibleFields, const UniString& sI
 //------------------------------------------------------------------------
 sal_Bool FmSearchDialog::Close()
 {
-    // Wenn der Close-Button disabled ist und man im Dialog ESC drueckt, dann wird irgendwo vom Frame trotzdem Close aufgerufen,
-    // was ich allerdings nicht will, wenn ich gerade mitten in einer (eventuell in einem extra Thread laufenden) Suche bin
+    // If the close button is disabled and ESC is pressed in a dialog,
+    // then Frame will call Close anyway, which I don't want to happen
+    // while I'm in the middle of a search (maybe one that's running
+    // in its own thread)
     if (!m_pbClose.IsEnabled())
         return sal_False;
     return ModalDialog::Close();
@@ -326,7 +325,7 @@ IMPL_LINK(FmSearchDialog, OnClickedFieldRadios, Button*, pButton)
         EnableSearchForDependees(sal_True);
     }
     else
-        // die Feldlistbox entsprechend en- oder disablen
+        // en- or disable field list box accordingly
         if (pButton == &m_rbSingleField)
         {
             m_lbField.Enable();
@@ -421,7 +420,7 @@ IMPL_LINK(FmSearchDialog, OnClickedSpecialSettings, Button*, pButton )
             aDlg->Execute();
 
 
-            INT32 nFlags = aDlg->GetTransliterationFlags();
+            sal_Int32 nFlags = aDlg->GetTransliterationFlags();
             m_pSearchEngine->SetTransliterationFlags(nFlags);
 
             m_cbCase.Check(m_pSearchEngine->GetCaseSensitive());
@@ -493,7 +492,7 @@ IMPL_LINK(FmSearchDialog, OnCheckBoxToggled, CheckBox*, pBox)
     {
         // die beiden jeweils anderen Boxes disablen oder enablen
         CheckBox* pBoxes[] = { &m_cbWildCard, &m_cbRegular, &m_cbApprox };
-        for (sal_uInt32 i=0; i<sizeof(pBoxes)/sizeof(CheckBox*); ++i)
+        for (sal_uInt32 i=0; i< SAL_N_ELEMENTS(pBoxes); ++i)
         {
             if (pBoxes[i] != pBox)
             {
@@ -565,7 +564,7 @@ void FmSearchDialog::InitContext(sal_Int16 nContext)
     fmscContext.nContext = nContext;
 
 #ifdef DBG_UTIL
-    sal_uInt32 nResult = 
+    sal_uInt32 nResult =
 #endif
     m_lnkContextSupplier.Call(&fmscContext);
     DBG_ASSERT(nResult > 0, "FmSearchDialog::InitContext : ContextSupplier didn't give me any controls !");
@@ -629,8 +628,7 @@ void FmSearchDialog::EnableSearchUI(sal_Bool bEnable)
 
     if ( !bEnable )
     {
-        // if one of my children has the focus, remember it 
-        // 104332 - 2002-10-17 - fs@openoffice.org
+        // if one of my children has the focus, remember it
         Window* pFocusWindow = Application::GetFocusWindow( );
         if ( pFocusWindow && IsChild( pFocusWindow ) )
             m_pPreSearchFocus = pFocusWindow;
@@ -665,7 +663,6 @@ void FmSearchDialog::EnableSearchUI(sal_Bool bEnable)
         {	// this means we're preparing for starting a search
             // In this case, EnableSearchForDependees disabled the search button
             // But as we're about to use it for cancelling the search, we really need to enable it, again
-            // 07.12.2001 - 95246 - fs@openoffice.org
             m_pbSearchAgain.Enable( sal_True );
         }
     }
@@ -678,7 +675,6 @@ void FmSearchDialog::EnableSearchUI(sal_Bool bEnable)
 
     if ( bEnable )
     {	// restore focus
-        // 104332 - 2002-10-17 - fs@openoffice.org
         if ( m_pPreSearchFocus )
         {
             m_pPreSearchFocus->GrabFocus();
@@ -809,7 +805,7 @@ IMPL_LINK(FmSearchDialog, OnSearchProgress, FmSearchProgress*, pProgress)
                 : RID_SVXERR_SEARCH_NORECORD;
             ErrorBox(this, CUI_RES(nErrorId)).Execute();
         }
-            // KEIN break !
+            // NO break !
         case FmSearchProgress::STATE_CANCELED:
             EnableSearchUI(sal_True);
             if (m_lnkCanceledNotFoundHdl.IsSet())
