@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -25,9 +26,6 @@
  *
  ************************************************************************/
 
-// MARKER(update_precomp.py): autogen include statement, do not remove
-#include "precompiled_cui.hxx"
-
 #include "connpooloptions.hxx"
 #include "connpooloptions.hrc"
 #include <svtools/editbrowsebox.hxx>
@@ -65,7 +63,7 @@ namespace offapp
 
         virtual	void Init();
                 void Update(const DriverPoolingSettings& _rSettings);
-        virtual String GetCellText( long nRow, USHORT nColId ) const;
+        virtual String GetCellText( long nRow, sal_uInt16 nColId ) const;
 
         // the handler will be called with a DriverPoolingSettings::const_iterator as parameter,
         // or NULL if no valid current row exists
@@ -82,13 +80,13 @@ namespace offapp
         sal_Bool	isModified() const;
 
     protected:
-        virtual void InitController( ::svt::CellControllerRef& rController, long nRow, USHORT nCol );
-        virtual ::svt::CellController* GetController( long nRow, USHORT nCol );
+        virtual void InitController( ::svt::CellControllerRef& rController, long nRow, sal_uInt16 nCol );
+        virtual ::svt::CellController* GetController( long nRow, sal_uInt16 nCol );
 
-        virtual void PaintCell( OutputDevice& rDev, const Rectangle& rRect, USHORT nColId ) const;
+        virtual void PaintCell( OutputDevice& rDev, const Rectangle& rRect, sal_uInt16 nColId ) const;
 
-        virtual BOOL SeekRow( long nRow );
-        virtual BOOL SaveModified();
+        virtual sal_Bool SeekRow( long nRow );
+        virtual sal_Bool SaveModified();
 
         virtual sal_Bool IsTabAllowed(sal_Bool _bForward) const;
 
@@ -97,7 +95,7 @@ namespace offapp
         virtual void CursorMoved();
 
     protected:
-        virtual sal_uInt32 GetTotalCellWidth(long nRow, USHORT nColId);
+        virtual sal_uInt32 GetTotalCellWidth(long nRow, sal_uInt16 nColId);
 
 
     private:
@@ -106,7 +104,6 @@ namespace offapp
 
     //--------------------------------------------------------------------
     DriverListControl::DriverListControl( Window* _pParent, const ResId& _rId)
-//		:DriverListControl_Base(_pParent, _rId, DBBF_NOROWPICTURE, BROWSER_AUTO_VSCROLL | BROWSER_AUTO_HSCROLL | BROWSER_COLUMNSELECTION | BROWSER_HLINESFULL | BROWSER_VLINESFULL | BROWSER_HIDESELECT | BROWSER_CURSOR_WO_FOCUS)
         :DriverListControl_Base(_pParent, _rId, EBBF_NOROWPICTURE, BROWSER_AUTO_VSCROLL | BROWSER_AUTO_HSCROLL | BROWSER_HIDECURSOR | BROWSER_AUTOSIZE_LASTCOL)
         ,m_aSeekRow(m_aSettings.end())
         ,m_sYes(ResId(STR_YES,*_rId.GetResMgr()))
@@ -216,7 +213,7 @@ namespace offapp
     }
 
     //--------------------------------------------------------------------
-    sal_uInt32 DriverListControl::GetTotalCellWidth(long nRow, USHORT nColId)
+    sal_uInt32 DriverListControl::GetTotalCellWidth(long nRow, sal_uInt16 nColId)
     {
         return GetDataWindow().GetTextWidth(GetCellText(nRow, nColId));
     }
@@ -240,7 +237,7 @@ namespace offapp
                     sReturn = String::CreateFromInt32(_rPos->nTimeoutSeconds);
                 break;
             default:
-                OSL_ENSURE(sal_False, "DriverListControl::implGetCellText: invalid column id!");
+                OSL_FAIL("DriverListControl::implGetCellText: invalid column id!");
         }
         return sReturn;
     }
@@ -254,12 +251,12 @@ namespace offapp
     }
 
     //--------------------------------------------------------------------
-    String DriverListControl::GetCellText( long nRow, USHORT nColId ) const
+    String DriverListControl::GetCellText( long nRow, sal_uInt16 nColId ) const
     {
         String sReturn;
         if (nRow > m_aSettings.size())
         {
-            OSL_ENSURE(sal_False, "DriverListControl::GetCellText: don't ask me for such rows!");
+            OSL_FAIL("DriverListControl::GetCellText: don't ask me for such rows!");
         }
         else
         {
@@ -269,25 +266,25 @@ namespace offapp
     }
 
     //--------------------------------------------------------------------
-    void DriverListControl::InitController( ::svt::CellControllerRef& rController, long nRow, USHORT nCol )
+    void DriverListControl::InitController( ::svt::CellControllerRef& rController, long nRow, sal_uInt16 nCol )
     {
         rController->GetWindow().SetText(GetCellText(nRow, nCol));
     }
 
     //--------------------------------------------------------------------
-    ::svt::CellController* DriverListControl::GetController( long /*nRow*/, USHORT /*nCol*/ )
+    ::svt::CellController* DriverListControl::GetController( long /*nRow*/, sal_uInt16 /*nCol*/ )
     {
         return NULL;
     }
 
     //--------------------------------------------------------------------
-    BOOL DriverListControl::SaveModified()
+    sal_Bool DriverListControl::SaveModified()
     {
-        return TRUE;
+        return sal_True;
     }
 
     //--------------------------------------------------------------------
-    BOOL DriverListControl::SeekRow( long _nRow )
+    sal_Bool DriverListControl::SeekRow( long _nRow )
     {
         DriverListControl_Base::SeekRow(_nRow);
 
@@ -300,7 +297,7 @@ namespace offapp
     }
 
     //--------------------------------------------------------------------
-    void DriverListControl::PaintCell( OutputDevice& rDev, const Rectangle& rRect, USHORT nColId ) const
+    void DriverListControl::PaintCell( OutputDevice& rDev, const Rectangle& rRect, sal_uInt16 nColId ) const
     {
         OSL_ENSURE(m_aSeekRow != m_aSettings.end(), "DriverListControl::PaintCell: invalid row!");
 
@@ -379,7 +376,7 @@ namespace offapp
             m_pDriverList->Update(pDriverSettings->getSettings());
         else
         {
-            OSL_ENSURE(sal_False, "ConnectionPoolOptionsPage::implInitControls: missing the DriverTimeouts item!");
+            OSL_FAIL("ConnectionPoolOptionsPage::implInitControls: missing the DriverTimeouts item!");
             m_pDriverList->Update(DriverPoolingSettings());
         }
         m_pDriverList->saveValue();
@@ -399,7 +396,7 @@ namespace offapp
     }
 
     //--------------------------------------------------------------------
-    BOOL ConnectionPoolOptionsPage::FillItemSet(SfxItemSet& _rSet)
+    sal_Bool ConnectionPoolOptionsPage::FillItemSet(SfxItemSet& _rSet)
     {
         commitTimeoutField();
 
@@ -505,3 +502,4 @@ namespace offapp
 //........................................................................
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
