@@ -71,9 +71,6 @@ bool BufferNode::isECOfBeforeModifyIncluded(sal_Int32 nIgnoredSecurityId) const
  *   RESULT
  *	bExist - true if a match found, false otherwise
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -118,9 +115,6 @@ void BufferNode::setReceivedAll()
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -153,9 +147,6 @@ void BufferNode::addElementCollector(const ElementCollector* pElementCollector)
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -184,9 +175,6 @@ void BufferNode::removeElementCollector(const ElementCollector* pElementCollecto
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -232,9 +220,6 @@ void BufferNode::setBlocker(const ElementMark* pBlocker)
  *	Because there is only one blocker permited for a BufferNode, so the
  *	old blocker on this BufferNode, if there is one, will be overcasted.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -267,9 +252,6 @@ rtl::OUString BufferNode::printChildren() const
  *   RESULT
  *	result - the information string
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -338,9 +320,6 @@ bool BufferNode::hasAnything() const
  *   RESULT
  *	bExist - true if there is, false otherwise.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -368,9 +347,6 @@ bool BufferNode::hasChildren() const
  *   RESULT
  *	bExist - true if there is, false otherwise.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -403,9 +379,6 @@ const BufferNode* BufferNode::getFirstChild() const
  *	child -	the first child BufferNode, or NULL if there is no child
  *	       	BufferNode.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -444,9 +417,6 @@ void BufferNode::addChild(const BufferNode* pChild, sal_Int32 nPosition)
  *	If the nPosition is -1, then the new child BufferNode is appended
  *	at the end.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -485,9 +455,6 @@ void BufferNode::addChild(const BufferNode* pChild)
  *   NOTES
  *	The new child BufferNode is appended at the end.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -514,9 +481,6 @@ void BufferNode::removeChild(const BufferNode* pChild)
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -553,9 +517,6 @@ sal_Int32 BufferNode::indexOfChild(const BufferNode* pChild) const
  *	index -	the index of that child BufferNode. If that child BufferNode
  *	       	is not found, -1 is returned.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -603,9 +564,6 @@ const BufferNode* BufferNode::childAt(sal_Int32 nIndex) const
  *	child -	the child BufferNode at index position, or NULL if the index
  *	       	is out of the range of children.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -649,9 +607,6 @@ const BufferNode* BufferNode::getNextSibling() const
  *   RESULT
  *	sibling - the next sibling BufferNode, or NULL if there is none.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -687,9 +642,6 @@ const BufferNode* BufferNode::isAncestor(const BufferNode* pDescendant) const
  *	bIs -	true if this BufferNode is an ancestor of the pDescendant, 
  *	     	false otherwise.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -742,9 +694,6 @@ bool BufferNode::isPrevious(const BufferNode* pFollowing) const
  *	bIs -	true if this BufferNode is ahead in the tree order, false
  *	     	otherwise.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -795,9 +744,6 @@ const BufferNode* BufferNode::getNextNodeByTreeOrder() const
  *	   node is;
  *	4. otherwise, no "next" node exists.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -878,9 +824,6 @@ void BufferNode::notifyBranch()
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -915,9 +858,6 @@ void BufferNode::notifyAncestor()
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -950,9 +890,6 @@ void BufferNode::elementCollectorNotify()
  *	child -	the first child BufferNode, or NULL if there is no child
  *	       	BufferNode.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -1043,9 +980,6 @@ bool BufferNode::isECInSubTreeIncluded(sal_Int32 nIgnoredSecurityId) const
  *   RESULT
  *	bExist - true if a match found, false otherwise.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -1110,9 +1044,6 @@ bool BufferNode::isECOfBeforeModifyInAncestorIncluded(sal_Int32 nIgnoredSecurity
  *   RESULT
  *	bExist - true if a match found, false otherwise.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -1158,9 +1089,6 @@ bool BufferNode::isBlockerInSubTreeIncluded(sal_Int32 nIgnoredSecurityId) const
  *   RESULT
  *	bExist - true if a match found, false otherwise.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -1212,9 +1140,6 @@ const BufferNode* BufferNode::getNextChild(const BufferNode* pChild) const
  *	nextChild -	the next child BufferNode after the pChild, or NULL if 
  *	there is none.
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -1260,9 +1185,6 @@ void BufferNode::freeAllChildren()
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	30.03.2004 -	the correct the memory leak bug
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
